@@ -136,12 +136,12 @@ def serve_redirects(request, handler, *rest):
 def serve_response(*path):
     """Serve up various respones with their correct response type
 
-    >>> zoom_js = zoom.tools.zoompath('web/www/static/zoom/zoom.js')
+    >>> zoom_js = zoom.tools.zoompath('zoom/_assets/web/www/static/zoom/zoom.js')
     >>> response = serve_response(zoom_js)
     >>> isinstance(response, JavascriptResponse)
     True
 
-    >>> zoom_path = zoom.tools.zoompath('web')
+    >>> zoom_path = zoom.tools.zoompath('zoom', '_assets', 'web')
     >>> response = serve_response(zoom_path, 'www/static/zoom/nada.js')
     >>> isinstance(response, JavascriptResponse)
     False
@@ -151,7 +151,7 @@ def serve_response(*path):
     >>> response.status
     '404 Not Found'
 
-    >>> zoom_path = zoom.tools.zoompath('web')
+    >>> zoom_path = zoom.tools.zoompath('zoom', '_assets', 'web')
     >>> response = serve_response(zoom_path, 'www/static/zoom/images')
     >>> isinstance(response, JavascriptResponse)
     False
@@ -176,20 +176,33 @@ def serve_response(*path):
         map=BinaryResponse,
         svg=SVGResponse,
     )
+    exists = os.path.exists
+    isfile = os.path.isfile
     pathname = os.path.realpath(os.path.join(*path))
+
     logger = logging.getLogger(__name__)
     logger.debug('attempting to serve up file %r', pathname)
-    if os.path.exists(pathname):
+
+    if not isfile(pathname) and pathname.endswith('.css'):
+        alt_pathname = pathname[:-3] + 'sass'
+        logger.debug('trying alt_pathname %r', alt_pathname)
+        if isfile(alt_pathname):
+            pathname = alt_pathname
+        else:
+            raise Exception('not a file')
+
+    if exists(pathname):
         pathnamel = pathname.lower()
         _, file_type = os.path.splitext(pathnamel)
         file_type = file_type[1:]
         response_type = known_types.get(file_type)
         if response_type:
 
-            with open(pathname, 'rb') as f:
-                data = f.read()
-
             if file_type == 'json':
+
+                with open(pathname, 'rb') as f:
+                    data = f.read()
+
                 # JSONResponse expects an object which it will seriaize
                 # so this unserializaing / reserializing an extra step
                 # which may be unnecessary.  For now, we'll use the
@@ -197,6 +210,14 @@ def serve_response(*path):
                 # create a different response type in this case.
                 data = zoom.jsonz.loads(data)
 
+            elif file_type == 'sass':
+                logger.warning('rendering sass file response %r', pathname)
+                data = zoom.tools.sass(pathname).encode('utf8')
+
+            else:
+                with open(pathname, 'rb') as f:
+                    data = f.read()
+
             return response_type(data)
 
         msg = 'unknown file type {!r}'.format(file_type)
@@ -262,7 +283,7 @@ def serve_static(request, handler, *rest):
             join(request.instance, 'static'),
             join(request.instance, 'www', 'static'),
             join(request.instance, '..', 'static'),
-            zoom.tools.zoompath('zoom', '_assets', 'www', 'static'),
+            zoom.tools.zoompath('zoom', '_assets', 'web', 'www', 'static'),
         ]))
         for location in locations:
             pathname = join(location, *request.route[1:])
@@ -294,13 +315,20 @@ def serve_themes(request, handler, *rest):
     False
     """
 
+    def existing(*path):
+        """Return existing file pathname or none"""
+        pathname = os.path.join(*path)
+        if pathname and os.path.isfile(pathname):
+            return pathname
+
     path = request.path[1:]
     site = request.site
-    existing = zoom.utils.existing
 
     pathname = path and (
         existing(site.theme_path, path) or
-        existing(site.default_theme_path, path)
+        existing(site.theme_path, path[:-4]+'.sass') or
+        existing(site.default_theme_path, path) or
+        existing(site.default_theme_path, path[:-4]+'.sass')
     )
     if pathname:
         return serve_response(pathname)
@@ -443,6 +471,8 @@ def serve_html(request, handler, *rest):
 
 
 def get_csrf_token(session):
+    """ test """
+
     """generate a csrf token
 
     >>> zoom.system.request.session = session = zoom.utils.Bunch()
